/* eslint-disable @typescript-eslint/no-namespace */
import { decodeMessage, encodeMessage, MaxLengthError, message } from 'protons-runtime';
import { alloc as uint8ArrayAlloc } from 'uint8arrays/alloc';
export var Node;
(function (Node) {
    let _codec;
    Node.codec = () => {
        if (_codec == null) {
            _codec = message((obj, w, opts = {}) => {
                if (opts.lengthDelimited !== false) {
                    w.fork();
                }
                if ((obj.level != null && obj.level !== 0)) {
                    w.uint32(8);
                    w.uint32(obj.level);
                }
                if (obj.key != null) {
                    w.uint32(18);
                    w.bytes(obj.key);
                }
                if ((obj.hash != null && obj.hash.byteLength > 0)) {
                    w.uint32(26);
                    w.bytes(obj.hash);
                }
                if (opts.lengthDelimited !== false) {
                    w.ldelim();
                }
            }, (reader, length, opts = {}) => {
                const obj = {
                    level: 0,
                    hash: uint8ArrayAlloc(0)
                };
                const end = length == null ? reader.len : reader.pos + length;
                while (reader.pos < end) {
                    const tag = reader.uint32();
                    switch (tag >>> 3) {
                        case 1: {
                            obj.level = reader.uint32();
                            break;
                        }
                        case 2: {
                            obj.key = reader.bytes();
                            break;
                        }
                        case 3: {
                            obj.hash = reader.bytes();
                            break;
                        }
                        default: {
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                }
                return obj;
            });
        }
        return _codec;
    };
    Node.encode = (obj) => {
        return encodeMessage(obj, Node.codec());
    };
    Node.decode = (buf, opts) => {
        return decodeMessage(buf, Node.codec(), opts);
    };
})(Node || (Node = {}));
export var Request;
(function (Request) {
    let GetRootRequest;
    (function (GetRootRequest) {
        let _codec;
        GetRootRequest.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {};
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetRootRequest.encode = (obj) => {
            return encodeMessage(obj, GetRootRequest.codec());
        };
        GetRootRequest.decode = (buf, opts) => {
            return decodeMessage(buf, GetRootRequest.codec(), opts);
        };
    })(GetRootRequest = Request.GetRootRequest || (Request.GetRootRequest = {}));
    let GetNodeRequest;
    (function (GetNodeRequest) {
        let _codec;
        GetNodeRequest.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if ((obj.level != null && obj.level !== 0)) {
                        w.uint32(8);
                        w.uint32(obj.level);
                    }
                    if (obj.key != null) {
                        w.uint32(18);
                        w.bytes(obj.key);
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        level: 0
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                obj.level = reader.uint32();
                                break;
                            }
                            case 2: {
                                obj.key = reader.bytes();
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetNodeRequest.encode = (obj) => {
            return encodeMessage(obj, GetNodeRequest.codec());
        };
        GetNodeRequest.decode = (buf, opts) => {
            return decodeMessage(buf, GetNodeRequest.codec(), opts);
        };
    })(GetNodeRequest = Request.GetNodeRequest || (Request.GetNodeRequest = {}));
    let GetChildrenRequest;
    (function (GetChildrenRequest) {
        let _codec;
        GetChildrenRequest.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if ((obj.level != null && obj.level !== 0)) {
                        w.uint32(8);
                        w.uint32(obj.level);
                    }
                    if (obj.key != null) {
                        w.uint32(18);
                        w.bytes(obj.key);
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        level: 0
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                obj.level = reader.uint32();
                                break;
                            }
                            case 2: {
                                obj.key = reader.bytes();
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetChildrenRequest.encode = (obj) => {
            return encodeMessage(obj, GetChildrenRequest.codec());
        };
        GetChildrenRequest.decode = (buf, opts) => {
            return decodeMessage(buf, GetChildrenRequest.codec(), opts);
        };
    })(GetChildrenRequest = Request.GetChildrenRequest || (Request.GetChildrenRequest = {}));
    let GetValuesRequest;
    (function (GetValuesRequest) {
        let _codec;
        GetValuesRequest.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (obj.keys != null) {
                        for (const value of obj.keys) {
                            w.uint32(10);
                            w.bytes(value);
                        }
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        keys: []
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                if (opts.limits?.keys != null && obj.keys.length === opts.limits.keys) {
                                    throw new MaxLengthError('Decode error - map field "keys" had too many elements');
                                }
                                obj.keys.push(reader.bytes());
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetValuesRequest.encode = (obj) => {
            return encodeMessage(obj, GetValuesRequest.codec());
        };
        GetValuesRequest.decode = (buf, opts) => {
            return decodeMessage(buf, GetValuesRequest.codec(), opts);
        };
    })(GetValuesRequest = Request.GetValuesRequest || (Request.GetValuesRequest = {}));
    let _codec;
    Request.codec = () => {
        if (_codec == null) {
            _codec = message((obj, w, opts = {}) => {
                if (opts.lengthDelimited !== false) {
                    w.fork();
                }
                if (obj.getRoot != null) {
                    w.uint32(10);
                    Request.GetRootRequest.codec().encode(obj.getRoot, w);
                }
                if (obj.getNode != null) {
                    w.uint32(18);
                    Request.GetNodeRequest.codec().encode(obj.getNode, w);
                }
                if (obj.getChildren != null) {
                    w.uint32(26);
                    Request.GetChildrenRequest.codec().encode(obj.getChildren, w);
                }
                if (obj.getValues != null) {
                    w.uint32(34);
                    Request.GetValuesRequest.codec().encode(obj.getValues, w);
                }
                if (opts.lengthDelimited !== false) {
                    w.ldelim();
                }
            }, (reader, length, opts = {}) => {
                const obj = {};
                const end = length == null ? reader.len : reader.pos + length;
                while (reader.pos < end) {
                    const tag = reader.uint32();
                    switch (tag >>> 3) {
                        case 1: {
                            obj.getRoot = Request.GetRootRequest.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getRoot
                            });
                            break;
                        }
                        case 2: {
                            obj.getNode = Request.GetNodeRequest.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getNode
                            });
                            break;
                        }
                        case 3: {
                            obj.getChildren = Request.GetChildrenRequest.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getChildren
                            });
                            break;
                        }
                        case 4: {
                            obj.getValues = Request.GetValuesRequest.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getValues
                            });
                            break;
                        }
                        default: {
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                }
                return obj;
            });
        }
        return _codec;
    };
    Request.encode = (obj) => {
        return encodeMessage(obj, Request.codec());
    };
    Request.decode = (buf, opts) => {
        return decodeMessage(buf, Request.codec(), opts);
    };
})(Request || (Request = {}));
export var Response;
(function (Response) {
    let GetRootResponse;
    (function (GetRootResponse) {
        let _codec;
        GetRootResponse.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (obj.root != null) {
                        w.uint32(10);
                        Node.codec().encode(obj.root, w);
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {};
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                obj.root = Node.codec().decode(reader, reader.uint32(), {
                                    limits: opts.limits?.root
                                });
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetRootResponse.encode = (obj) => {
            return encodeMessage(obj, GetRootResponse.codec());
        };
        GetRootResponse.decode = (buf, opts) => {
            return decodeMessage(buf, GetRootResponse.codec(), opts);
        };
    })(GetRootResponse = Response.GetRootResponse || (Response.GetRootResponse = {}));
    let GetNodeResponse;
    (function (GetNodeResponse) {
        let _codec;
        GetNodeResponse.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (obj.node != null) {
                        w.uint32(10);
                        Node.codec().encode(obj.node, w);
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {};
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                obj.node = Node.codec().decode(reader, reader.uint32(), {
                                    limits: opts.limits?.node
                                });
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetNodeResponse.encode = (obj) => {
            return encodeMessage(obj, GetNodeResponse.codec());
        };
        GetNodeResponse.decode = (buf, opts) => {
            return decodeMessage(buf, GetNodeResponse.codec(), opts);
        };
    })(GetNodeResponse = Response.GetNodeResponse || (Response.GetNodeResponse = {}));
    let GetChildrenResponse;
    (function (GetChildrenResponse) {
        let _codec;
        GetChildrenResponse.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (obj.children != null) {
                        for (const value of obj.children) {
                            w.uint32(10);
                            Node.codec().encode(value, w);
                        }
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        children: []
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                if (opts.limits?.children != null && obj.children.length === opts.limits.children) {
                                    throw new MaxLengthError('Decode error - map field "children" had too many elements');
                                }
                                obj.children.push(Node.codec().decode(reader, reader.uint32(), {
                                    limits: opts.limits?.children$
                                }));
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetChildrenResponse.encode = (obj) => {
            return encodeMessage(obj, GetChildrenResponse.codec());
        };
        GetChildrenResponse.decode = (buf, opts) => {
            return decodeMessage(buf, GetChildrenResponse.codec(), opts);
        };
    })(GetChildrenResponse = Response.GetChildrenResponse || (Response.GetChildrenResponse = {}));
    let GetValuesResponse;
    (function (GetValuesResponse) {
        let _codec;
        GetValuesResponse.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (obj.values != null) {
                        for (const value of obj.values) {
                            w.uint32(10);
                            w.bytes(value);
                        }
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        values: []
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                if (opts.limits?.values != null && obj.values.length === opts.limits.values) {
                                    throw new MaxLengthError('Decode error - map field "values" had too many elements');
                                }
                                obj.values.push(reader.bytes());
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        GetValuesResponse.encode = (obj) => {
            return encodeMessage(obj, GetValuesResponse.codec());
        };
        GetValuesResponse.decode = (buf, opts) => {
            return decodeMessage(buf, GetValuesResponse.codec(), opts);
        };
    })(GetValuesResponse = Response.GetValuesResponse || (Response.GetValuesResponse = {}));
    let Abort;
    (function (Abort) {
        let _codec;
        Abort.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if ((obj.cooldown != null && obj.cooldown !== 0)) {
                        w.uint32(8);
                        w.uint32(obj.cooldown);
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        cooldown: 0
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                obj.cooldown = reader.uint32();
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        Abort.encode = (obj) => {
            return encodeMessage(obj, Abort.codec());
        };
        Abort.decode = (buf, opts) => {
            return decodeMessage(buf, Abort.codec(), opts);
        };
    })(Abort = Response.Abort || (Response.Abort = {}));
    let _codec;
    Response.codec = () => {
        if (_codec == null) {
            _codec = message((obj, w, opts = {}) => {
                if (opts.lengthDelimited !== false) {
                    w.fork();
                }
                if (obj.getRoot != null) {
                    w.uint32(10);
                    Response.GetRootResponse.codec().encode(obj.getRoot, w);
                }
                if (obj.getNode != null) {
                    w.uint32(18);
                    Response.GetNodeResponse.codec().encode(obj.getNode, w);
                }
                if (obj.getChildren != null) {
                    w.uint32(26);
                    Response.GetChildrenResponse.codec().encode(obj.getChildren, w);
                }
                if (obj.getValues != null) {
                    w.uint32(34);
                    Response.GetValuesResponse.codec().encode(obj.getValues, w);
                }
                if (obj.abort != null) {
                    w.uint32(42);
                    Response.Abort.codec().encode(obj.abort, w);
                }
                if (opts.lengthDelimited !== false) {
                    w.ldelim();
                }
            }, (reader, length, opts = {}) => {
                const obj = {};
                const end = length == null ? reader.len : reader.pos + length;
                while (reader.pos < end) {
                    const tag = reader.uint32();
                    switch (tag >>> 3) {
                        case 1: {
                            obj.getRoot = Response.GetRootResponse.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getRoot
                            });
                            break;
                        }
                        case 2: {
                            obj.getNode = Response.GetNodeResponse.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getNode
                            });
                            break;
                        }
                        case 3: {
                            obj.getChildren = Response.GetChildrenResponse.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getChildren
                            });
                            break;
                        }
                        case 4: {
                            obj.getValues = Response.GetValuesResponse.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.getValues
                            });
                            break;
                        }
                        case 5: {
                            obj.abort = Response.Abort.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.abort
                            });
                            break;
                        }
                        default: {
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                }
                return obj;
            });
        }
        return _codec;
    };
    Response.encode = (obj) => {
        return encodeMessage(obj, Response.codec());
    };
    Response.decode = (buf, opts) => {
        return decodeMessage(buf, Response.codec(), opts);
    };
})(Response || (Response = {}));
